@@ -84,7 +84,7 @@ class MNIST_worker:
 		self.model.add(Dense(10, activation="softmax")) # Добавляем полносвязный слой на 10 нейронов с softmax-активацией
 		print('Создана модель нейронной сети.')
 		print('Схема созданной модели:')
-		self.model.summary()
+		#self.model.summary()
 		
 	def createModel(self, tp):
 		if (tp == 'Полносвязная'):
@@ -231,11 +231,11 @@ def addLayer(typeLayer = 'Dense', countNeurons = 128, kernelSize=(2,2)):
 def addOutLayer(typeLayer = 'Dense', countNeurons = 128, kernelSize=(2,2)):
 	worker.addLayer(typeLayer, countNeurons,kernelSize, 'softmax')
 	print('*** Нейронная сеть создана ***')
-	print('Схема нейронной сети:')
-	tf.keras.utils.plot_model(worker.model, to_file='scheme.png', show_shapes=True)
-	image = plt.imread('scheme.png')
-	plt.figure(figsize=(8,8))
-	plt.imshow(image)
-	plt.axis('off')
-	plt.show()
+	#print('Схема нейронной сети:')
+	#tf.keras.utils.plot_model(worker.model, to_file='scheme.png', show_shapes=True)
+	#image = plt.imread('scheme.png')
+	#plt.figure(figsize=(8,8))
+	#plt.imshow(image)
+	#plt.axis('off')
+	#plt.show()
 	worker.firstLayer = True
